@@ -673,6 +673,8 @@ test_that("unmarshal error with message in 'Message'", {
   out <- req$error
   expect_equal(out$code, "FooException")
   expect_equal(out$message, "Foo")
+  expect_equal(out$status_code, 400)
+  expect_equal(out$error_response$Message, "Foo")
 })
 
 test_that("unmarshal error with message in 'message'", {
@@ -685,6 +687,8 @@ test_that("unmarshal error with message in 'message'", {
   out <- req$error
   expect_equal(out$code, "FooException")
   expect_equal(out$message, "Foo")
+  expect_equal(out$status_code, 400)
+  expect_equal(out$error_response$message, "Foo")
 })
 
 test_that("unmarshal error with no message", {
@@ -697,4 +701,6 @@ test_that("unmarshal error with no message", {
   out <- req$error
   expect_equal(out$code, "FooException")
   expect_equal(out$message, "")
+  expect_equal(out$status_code, 400)
+  expect_equal(out$error_response$`__type`, "FooException")
 })
